/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __LOCKING_SHARE_MODE_LOCK_PRIVATE_H__
#define __LOCKING_SHARE_MODE_LOCK_PRIVATE_H__

struct share_mode_lock;
struct share_mode_data;

NTSTATUS share_mode_lock_access_private_data(struct share_mode_lock *lck,
					     struct share_mode_data **data);

#endif
